FermiLib Plugin to interface with PySCF
=======================================

This repository contains a plugin which allows `FermiLib <http://github.com/ProjectQ-Framework/FermiLib>`__ (licensed under Apache 2) to interface with the open-source quantum chemistry package `PySCF <https://github.com/sunqm/pyscf>`__ (licensed under BSD-2-Clause).

License
-------

This plugin is released under the Apache 2 license.
